@@ -1,10 +1,8 @@
 # -*- coding: utf-8 -*
 from .lca import LCA
-from .simple_regionalized import SimpleRegionalizedLCA
 from .monte_carlo import MonteCarloLCA, ParallelMonteCarlo, MultiMonteCarlo
 from .mc_vector import ParameterVectorLCA
-from .graph_traversal import GraphTraversal, edge_cutter, node_pruner, \
-    d3_fd_graph_formatter
+from .graph_traversal import GraphTraversal
 from .matrices import MatrixBuilder, TechnosphereBiosphereMatrixBuilder
 
-__version__ = (0, 10, 2)
+__version__ = (0, 11)
